KeySpans

Struct KeySpans 

pub struct KeySpans { /* private fields */ }
Available on crate feature serde only.
KeySpans associates nested values with their full path from the first value as a Vec of Strings.

Sequence indices are also turned into strings.

Keys that cannot be represented as strings will be replaced by ???.